@@ -19,7 +19,7 @@ from gnutls.errors import *
 
 
 class KeepRunning:
-    """Return this class from a recurent function to indicate that it should keep running"""
+    """Return this class from a recurrent function to indicate that it should keep running"""
     pass
 
 class RecurrentCall(object):
@@ -94,19 +94,14 @@ class TLSMixin:
             return e
 
     def _postLoseConnection(self):
-        self.doRead = self._sendBye
-        self.startReading()
-        return self._sendBye()
-
-    def _sendBye(self):
         try:
             self.socket.bye()
         except OperationWouldBlock, e:
-            return None
+            # Since we do not continue to use the connection after closing TLS
+            # we do not need to wait for the bye notification acknowledgement.
+            pass
         except GNUTLSError, e:
             return e
-        self.stopReading()
-        del self.doRead
         return getattr(self, '_close_reason', main.CONNECTION_DONE)
 
 
@@ -122,7 +117,7 @@ class TLSClient(TLSMixin, tcp.Client):
         sock = tcp.Client.createInternetSocket(self)
         return ClientSession(sock, self.credentials)
 
-    def _recurentVerify(self):
+    def _recurrentVerify(self):
         if not self.connected or self.disconnecting:
             return
         try:
@@ -148,7 +143,7 @@ class TLSClient(TLSMixin, tcp.Client):
         credentials.verify_callback(session.peer_certificate, preverify_status)
         
         if credentials.verify_period > 0:
-            self.__watchdog = RecurrentCall(credentials.verify_period, self._recurentVerify)
+            self.__watchdog = RecurrentCall(credentials.verify_period, self._recurrentVerify)
 
     def doHandshake(self):
         self.stopWriting()
@@ -214,7 +209,7 @@ class TLSServer(TLSMixin, tcp.Server):
         self.credentials = server.credentials
         tcp.Server.__init__(self, sock, protocol, client, server, sessionno)
 
-    def _recurentVerify(self):
+    def _recurrentVerify(self):
         if not self.connected or self.disconnecting:
             return
         try:
@@ -240,7 +235,7 @@ class TLSServer(TLSMixin, tcp.Server):
         credentials.verify_callback(session.peer_certificate, preverify_status)
         
         if credentials.verify_period > 0:
-            self.__watchdog = RecurrentCall(credentials.verify_period, self._recurentVerify)
+            self.__watchdog = RecurrentCall(credentials.verify_period, self._recurrentVerify)
 
     def doHandshake(self):
         self.stopWriting()
